@@ -76,7 +76,7 @@ static void
 my_error (gchar *err_message)
 {
 	gchar *m = g_strdup_printf ("%s failed", err_message);
-	g_warning (m);
+	g_warning ("%s", m);
 	g_free (m);
 	exit (1);
 }
